Learn R Programming

macrosyntR (version 0.3.3)

load_orthologs: load orthologs with their genomic coordinates.

Description

Puts together the table of orthologous genes with their genomic coordinates in the two or more species. It outputs a data.frame shaped as following : sp1.ID,sp1.Chr,sp1.Start,sp1.End,sp1.Index,sp2.ID,sp2.Chr,sp2.Start,sp2.End,sp2.Index,...

Usage

load_orthologs(
  orthologs_table,
  sp1_bed = NULL,
  sp2_bed = NULL,
  bedfiles = NULL
)

Value

dataframe composed of genomic coordinates and relative index of orthologs on both species

Arguments

orthologs_table

character. Full path to the orthologs table (format : geneID_on_species1 geneID_on_species2 geneID_on_speciesN)

sp1_bed

(deprecated) character. Full path to the genomic coordinates of the genes on species1

sp2_bed

(deprecated) character. Full path to the genomic coordinates of the genes on species2

bedfiles

array. List of full paths to the genomic coordinates ordered as in the appearing order of the orthologs_table (BED format)

Examples

Run this code
# basic usage of load_orthologs for two species :

orthologs_file <- system.file("extdata","Bflo_vs_Pyes.tab",package="macrosyntR")
bedfile_sp1 <- system.file("extdata","Bflo.bed",package="macrosyntR")
bedfile_sp2 <- system.file("extdata","Pyes.bed",package="macrosyntR")


my_orthologs <- load_orthologs(orthologs_table = orthologs_file,
                               bedfiles = c(bedfile_sp1,bedfile_sp2))
# example with 3 species :
orthologs_file <- system.file("extdata","Single_copy_orthologs.tsv",package="macrosyntR")
bedfile_sp3 <- system.file("extdata","Pech.bed",package="macrosyntR")

my_orthologs <- load_orthologs(orthologs_table = orthologs_file,
                               bedfiles = c(bedfile_sp1,bedfile_sp2,bedfile_sp3))


Run the code above in your browser using DataLab