Learn R Programming

macrosyntR (version 0.3.3)

reorder_multiple_macrosyntenies: Reorder the chromosomes of two or more species before plotting

Description

This is a function to reorder an orthologs_df, same as reorder_macrosynteny, but it handles tables with more than 2 species.

Usage

reorder_multiple_macrosyntenies(orthologs_df)

Value

A dataframe object

Arguments

orthologs_df

dataframe. orthologs with genomic coordinates loaded with load_orthologs()

See Also

load_orthologs()

compute_macrosynteny()

reorder_macrosynteny()

Examples

Run this code
# basic usage of reorder_macrosynteny : 

orthologs_table <- system.file("extdata","my_orthologs.tab",package="macrosyntR")

my_orthologs <- read.table(orthologs_table,header=TRUE)

my_orthologs_reordered <- reorder_multiple_macrosyntenies(my_orthologs)

Run the code above in your browser using DataLab