Learn R Programming

macrosyntR (version 0.3.3)

subset_linkage_orthologs: Subset Orthologs contained in conserved linkage groups

Description

This is a function to subset an orthologs_df and keep only the orthologs that are within significant linkage groups computed by the function compute_linkage_groups().

Usage

subset_linkage_orthologs(orthologs_df, linkages = NULL)

Value

A dataframe object

Arguments

orthologs_df

dataframe. orthologs with genomic coordinates loaded with load_orthologs()

linkages

dataframe. table listing the linkage groups as returned by the function compute_linkage_groups()

See Also

load_orthologs()

compute_linkage_groups()

Examples

Run this code
# basic usage of compute_linkage_groups: 

orthologs_table <- system.file("extdata","my_orthologs.tab",package="macrosyntR")

my_orthologs <- read.table(orthologs_table,header=TRUE)
                               
my_macrosynteny <- compute_linkage_groups(my_orthologs)

Run the code above in your browser using DataLab